@@ -590,7 +590,7 @@ def test_is_nongeneric_url(url, exp_res):
 @pytest.mark.parametrize(
     'newtag, exp_res',
     [
-        (None, ('http://example.com', 'text1', None, None, 0, True)),
+        (None, ('http://example.com', 'text1', ',', None, 0, True)),
         ('tag1', ('http://example.com', 'text1', ',tag1,', None, 0, True)),
     ]
 )
@@ -604,7 +604,7 @@ def test_import_md(tmpdir, newtag, exp_res):
 @pytest.mark.parametrize(
     'newtag, exp_res',
     [
-        (None, ('http://example.com', 'text1', None, None, 0, True)),
+        (None, ('http://example.com', 'text1', ',tag1,:tag2,tag:3,tag4:,tag::5,tag:6:,', None, 0, True)),
         ('tag0', ('http://example.com', 'text1', ',tag0,tag1,:tag2,tag:3,tag4:,tag::5,tag:6:,', None, 0, True)),
     ]
 )
@@ -770,3 +770,18 @@ def test_convert_bookmark_set(export_type, exp_res, monkeypatch):
         res = convert_bookmark_set(bms, export_type=export_type)
         assert res['count'] == 3
         assert exp_res == res['data']
+
+
+@pytest.mark.parametrize('tags,data', [
+    [',', '\n'],
+    [',tag1,tag2,', ' :tag1:tag2:\n'],
+    [',word1 word2,', ' :word1_word2:\n'],
+    [',word1:word2,', ' :word1_word2:\n'],
+    [',##tag##,', ' :_tag_:\n'],
+    [',##tag##,!!tag!!,', ' :_tag_:\n'],
+    [',home / personal,', ' :home_personal:\n'],
+])
+def test_convert_tags_to_org_mode_tags(tags, data):
+    from buku import convert_tags_to_org_mode_tags
+    res = convert_tags_to_org_mode_tags(tags)
+    assert res == data
